char * gluErrorString(error)
char * gluGetString(name)

int glpHasGLUT()
int glpHasGPGPU()
int glpRasterFont(name,base,number,d)
int glpXNextEvent(d=dpy)

int glutBitmapHeight(font)
int glutBitmapLength(font, string)
int glutBitmapWidth(font, character)
int glutCreateMenu(handler=0, ...)
int glutCreateSubWindow(win, x, y, width, height)
int glutCreateWindow(name)
int glutDeviceGet(info)
int glutEnterGameMode()
int glutExtensionSupported(extension)
int glutGameModeGet(mode)
int glutGet(state)
int glutGetMenu()
int glutGetModifiers()
int glutGetWindow()
int glutLayerGet(info)
int glutStrokeWidth(font, character)

static SV * neoconstant(char * name, int arg)
static int not_here(s)

glAccum(op, value)
glActiveTextureARB(texture)
glAlphaFunc(func, ref)
glAreTexturesResidentEXT_p(...)
glAreTexturesResident_c(n, textures, residences)
glAreTexturesResident_p(...)
glAreTexturesResident_s(n, textures, residences)
glArrayElement(i)
glArrayElementEXT(i)
glAttachObjectARB(containerObj, obj)
glBegin(mode)
glBindAttribLocationARB(programObj, index, name)
glBindBufferARB(target,buffer)
glBindFramebufferEXT(target,framebuffer)
glBindProgramARB(target,program)
glBindRenderbufferEXT(target,renderbuffer)
glBindTexture(target, texture)
glBindTextureEXT(target, texture)
glBitmap_c(width, height, xorig, yorig, xmove, ymove, bitmap)
glBitmap_p(width, height, xorig, yorig, xmove, ymove, ...)
glBitmap_s(width, height, xorig, yorig, xmove, ymove, bitmap)
glBlendColor(red, green, blue, alpha)
glBlendColorEXT(red, green, blue, alpha)
glBlendEquation(mode)
glBlendEquationEXT(mode)
glBlendFunc(sfactor, dfactor)
glBufferDataARB_c(target,size,data,usage)
glBufferDataARB_p(target,oga,usage)
glBufferDataARB_s(target,size,data,usage)
glBufferSubDataARB_c(target,offset,size,data)
glBufferSubDataARB_p(target,offset,oga)
glBufferSubDataARB_s(target,offset,size,data)
glCallList(list)
glCallLists_c(n, type, lists)
glCallLists_p(...)
glCallLists_s(n, type, lists)
glCheckFramebufferStatusEXT(target)
glClampColorARB(target,clamp)
glClear(mask)
glClearAccum(red, green, blue, alpha)
glClearColor(red, green, blue, alpha)
glClearDepth(depth)
glClearIndex(c)
glClearStencil(s)
glClientActiveTextureARB(texture)
glClipPlane_c(plane, eqn)
glClipPlane_p(plane, eqn0, eqn1, eqn2, eqn3)
glClipPlane_s(plane, eqn)
glColor3b(red, green, blue)
glColor3bv_c(v)
glColor3bv_p(red, green, blue)
glColor3bv_s(v)
glColor3d(red, green, blue)
glColor3dv_c(v)
glColor3dv_p(red, green, blue)
glColor3dv_s(v)
glColor3f(red, green, blue)
glColor3fv_c(v)
glColor3fv_p(red, green, blue)
glColor3fv_s(v)
glColor3i(red, green, blue)
glColor3iv_c(v)
glColor3iv_p(red, green, blue)
glColor3iv_s(v)
glColor3s(red, green, blue)
glColor3sv_c(v)
glColor3sv_p(red, green, blue)
glColor3sv_s(v)
glColor3ub(red, green, blue)
glColor3ubv_c(v)
glColor3ubv_p(red, green, blue)
glColor3ubv_s(v)
glColor3ui(red, green, blue)
glColor3uiv_c(v)
glColor3uiv_p(red, green, blue)
glColor3uiv_s(v)
glColor3us(red, green, blue)
glColor3usv_c(v)
glColor3usv_p(red, green, blue)
glColor3usv_s(v)
glColor4b(red, green, blue, alpha)
glColor4bv_c(v)
glColor4bv_p(red, green, blue, alpha)
glColor4bv_s(v)
glColor4d(red, green, blue, alpha)
glColor4dv_c(v)
glColor4dv_p(red, green, blue, alpha)
glColor4dv_s(v)
glColor4f(red, green, blue, alpha)
glColor4fv_c(v)
glColor4fv_p(red, green, blue, alpha)
glColor4fv_s(v)
glColor4i(red, green, blue, alpha)
glColor4iv_c(v)
glColor4iv_p(red, green, blue, alpha)
glColor4iv_s(v)
glColor4s(red, green, blue, alpha)
glColor4sv_c(v)
glColor4sv_p(red, green, blue, alpha)
glColor4sv_s(v)
glColor4ub(red, green, blue, alpha)
glColor4ubv_c(v)
glColor4ubv_p(red, green, blue, alpha)
glColor4ubv_s(v)
glColor4ui(red, green, blue, alpha)
glColor4uiv_c(v)
glColor4uiv_p(red, green, blue, alpha)
glColor4uiv_s(v)
glColor4us(red, green, blue, alpha)
glColor4usv_c(v)
glColor4usv_p(red, green, blue, alpha)
glColor4usv_s(v)
glColorMask(red, green, blue, alpha)
glColorMaterial(face, mode)
glColorPointerEXT_c(size, type, stride, count, pointer)
glColorPointerEXT_oga(size, oga)
glColorPointerEXT_s(size, type, stride, count, pointer)
glColorPointer_c(size, type, stride, pointer)
glColorPointer_p(size, oga)
glColorPointer_s(size, type, stride, pointer)
glCompileShaderARB(shaderObj)
glCopyPixels(x, y, width, height, type)
glCopyTexImage1D(target, level, internalFormat, x, y, width, border)
glCopyTexImage1DEXT(target, level, internalFormat, x, y, width, border)
glCopyTexImage2D(target, level, internalFormat, x, y, width, height, border)
glCopyTexImage2DEXT(target, level, internalFormat, x, y, width, height, border)
glCopyTexSubImage1D(target, level, xoffset, x, y, width)
glCopyTexSubImage1DEXT(target, level, xoffset, x, y, width)
glCopyTexSubImage2D(target, level, xoffset, yoffset, x, y, width, height)
glCopyTexSubImage2DEXT(target, level, xoffset, yoffset, x, y, width, height)
glCopyTexSubImage3D(target, level, xoffset, yoffset, zoffset, x, y, width, height)
glCopyTexSubImage3DEXT(target, level, xoffset, yoffset, zoffset, x, y, width, height)
glCreateProgramObjectARB()
glCreateShaderObjectARB(shaderType)
glCullFace(mode)
glDeleteBuffersARB_c(n,buffers)
glDeleteBuffersARB_p(...)
glDeleteBuffersARB_s(n,buffers)
glDeleteFramebuffersEXT_c(n,framebuffers)
glDeleteFramebuffersEXT_p(...)
glDeleteFramebuffersEXT_s(n,framebuffers)
glDeleteLists(list, range)
glDeleteObjectARB(obj)
glDeleteProgramsARB_c(n,programs)
glDeleteProgramsARB_p(...)
glDeleteProgramsARB_s(n,programs)
glDeleteRenderbuffersEXT_c(n,renderbuffers)
glDeleteRenderbuffersEXT_p(...)
glDeleteRenderbuffersEXT_s(n,renderbuffers)
glDeleteTexturesEXT_p(...);
glDeleteTextures_c(items, list)
glDeleteTextures_p(...)
glDeleteTextures_s(items, list)
glDepthFunc(func)
glDepthMask(flag)
glDepthRange(zNear, zFar)
glDetachObjectARB(containerObj, attachedObj)
glDisable(cap)
glDisableClientState(cap)
glDisableVertexAttribArrayARB(index)
glDrawArrays(mode, first, count)
glDrawArraysEXT(mode, first, count)
glDrawBuffer(mode)
glDrawBuffersARB_c(n,buffers)
glDrawBuffersARB_p(...)
glDrawBuffersARB_s(n,buffers)
glDrawBuffers_c(n,buffers)
glDrawBuffers_p(...)
glDrawBuffers_s(n,buffers)
glDrawElements_c(mode, count, type, indices)
glDrawElements_p(mode, ...)
glDrawElements_s(mode, count, type, indices)
glDrawPixels_c(width, height, format, type, pixels)
glDrawPixels_p(width, height, format, type, ...)
glDrawPixels_s(width, height, format, type, pixels)
glDrawRangeElements_c(mode, start, end, count, type, indices)
glDrawRangeElements_p(mode, start, count, ...)
glDrawRangeElements_s(mode, start, end, count, type, indices)
glEdgeFlag(flag)
glEdgeFlagPointerEXT_c(stride, count, pointer)
glEdgeFlagPointerEXT_oga(oga)
glEdgeFlagPointerEXT_s(stride, count, pointer)
glEdgeFlagPointer_c(stride, pointer)
glEdgeFlagPointer_p(oga)
glEdgeFlagPointer_s(stride, pointer)
glEnable(cap)
glEnableClientState(cap)
glEnableVertexAttribArrayARB(index)
glEnd()
glEndList()
glEvalCoord1d(u)
glEvalCoord1f(u)
glEvalCoord2d(u, v)
glEvalCoord2f(u, v)
glEvalMesh1(mode, i1, i2)
glEvalMesh2(mode, i1, i2, j1, j2)
glEvalPoint1(i)
glEvalPoint2(i, j)
glFeedbackBuffer_c(size, type, buffer)
glFinish()
glFlush()
glFogf(pname, param)
glFogfv_c(pname, params)
glFogfv_p(pname, param1, param2=0, param3=0, param4=0)
glFogfv_s(pname, params)
glFogi(pname, param)
glFogiv_c(pname, params)
glFogiv_p(pname, param1, param2=0, param3=0, param4=0)
glFogiv_s(pname, params)
glFramebufferRenderbufferEXT(target,attachment,renderbuffertarget,renderbuffer)
glFramebufferTexture1DEXT(target,attachment,textarget,texture,level)
glFramebufferTexture2DEXT(target,attachment,textarget,texture,level)
glFramebufferTexture3DEXT(target,attachment,textarget,texture,level,zoffset)
glFrontFace(mode)
glFrustum(left, right, bottom, top, zNear, zFar)
glGenBuffersARB_c(n,buffers)
glGenBuffersARB_p(n)
glGenBuffersARB_s(n,buffers)
glGenFramebuffersEXT_c(n,framebuffers)
glGenFramebuffersEXT_p(n)
glGenFramebuffersEXT_s(n,framebuffers)
glGenLists(range)
glGenProgramsARB_c(n,programs)
glGenProgramsARB_p(n)
glGenProgramsARB_s(n,programs)
glGenRenderbuffersEXT_c(n,renderbuffers)
glGenRenderbuffersEXT_p(n)
glGenRenderbuffersEXT_s(n,renderbuffers)
glGenTexturesEXT_p(n)
glGenTextures_c(n, textures)
glGenTextures_p(n)
glGenTextures_s(n, textures)
glGenerateMipmapEXT(target)
glGetActiveAttribARB_c(programObj, index, maxLength, length, size, type, name)
glGetActiveAttribARB_p(programObj, index)
glGetActiveAttribARB_s(programObj, index, maxLength, length, size, type, name)
glGetActiveUniformARB_c(programObj, index, maxLength, length, size, type, name)
glGetActiveUniformARB_p(programObj, index)
glGetActiveUniformARB_s(programObj, index, maxLength, length, size, type, name)
glGetAttachedObjectsARB_c(containerObj, maxCount, count, obj)
glGetAttachedObjectsARB_p(containerObj)
glGetAttachedObjectsARB_s(containerObj, maxCount, count, obj)
glGetAttribLocationARB_c(programObj, name)
glGetAttribLocationARB_p(programObj, ...)
glGetBooleanv_c(pname, params)
glGetBooleanv_p(param)
glGetBooleanv_s(pname, params)
glGetBufferParameterivARB_c(target,pname,params)
glGetBufferParameterivARB_p(target,pname)
glGetBufferParameterivARB_s(target,pname,params)
glGetBufferPointervARB_c(target,pname,params)
glGetBufferPointervARB_p(target,pname,...)
glGetBufferPointervARB_s(target,pname,params)
glGetBufferSubDataARB_c(target,offset,size,data)
glGetBufferSubDataARB_p(target,offset,count,...)
glGetBufferSubDataARB_s(target,offset,size,data)
glGetClipPlane_c(plane, eqn)
glGetClipPlane_p(plane)
glGetClipPlane_s(plane, eqn)
glGetDoublev_c(pname, params)
glGetDoublev_p(param)
glGetDoublev_s(pname, params)
glGetError()
glGetFloatv_c(pname, params)
glGetFloatv_p(param)
glGetFloatv_s(pname, params)
glGetFramebufferAttachmentParameterivEXT_c(target,attachment,pname,params)
glGetFramebufferAttachmentParameterivEXT_s(target,attachment,pname,params)
glGetHandleARB(pname)
glGetInfoLogARB_c(obj, maxLength, length, infoLog)
glGetInfoLogARB_p(obj)
glGetIntegerv_c(pname, params)
glGetIntegerv_p(param)
glGetIntegerv_s(pname, params)
glGetLightfv_c(light, pname, p)
glGetLightfv_p(light, pname)
glGetLightfv_s(light, pname, p)
glGetLightiv_c(light, pname, p)
glGetLightiv_p(light, pname)
glGetLightiv_s(light, pname, p)
glGetMapdv_c(target, query, v)
glGetMapdv_p(target, query)
glGetMapdv_s(target, query, v)
glGetMapfv_c(target, query, v)
glGetMapfv_p(target, query)
glGetMapfv_s(target, query, v)
glGetMapiv_c(target, query, v)
glGetMapiv_p(target, query)
glGetMapiv_s(target, query, v)
glGetMaterialfv_c(face, query, params)
glGetMaterialfv_p(face, query)
glGetMaterialfv_s(face, query, params)
glGetMaterialiv_c(face, query, params)
glGetMaterialiv_p(face, query)
glGetMaterialiv_s(face, query, params)
glGetObjectParameterfvARB_c(obj,pname,params)
glGetObjectParameterfvARB_p(obj,pname)
glGetObjectParameterfvARB_s(obj,pname,params)
glGetObjectParameterivARB_c(obj,pname,params)
glGetObjectParameterivARB_p(obj,pname)
glGetObjectParameterivARB_s(obj,pname,params)
glGetPixelMapfv_c(map, values)
glGetPixelMapfv_p(map)
glGetPixelMapfv_s(map, values)
glGetPixelMapuiv_c(map, values)
glGetPixelMapuiv_p(map)
glGetPixelMapuiv_s(map, values)
glGetPixelMapusv_c(map, values)
glGetPixelMapusv_p(map)
glGetPixelMapusv_s(map, values)
glGetPointerv_c(pname, params)
glGetPointerv_p(pname)
glGetPointerv_s(pname, params)
glGetPolygonStipple_c(mask)
glGetPolygonStipple_p()
glGetPolygonStipple_s(mask)
glGetProgramEnvParameterdvARB_c(target,index,params)
glGetProgramEnvParameterdvARB_p(target,index)
glGetProgramEnvParameterdvARB_s(target,index,params)
glGetProgramEnvParameterfvARB_c(target,index,params)
glGetProgramEnvParameterfvARB_p(target,index)
glGetProgramEnvParameterfvARB_s(target,index,params)
glGetProgramLocalParameterdvARB_c(target,index,params)
glGetProgramLocalParameterdvARB_p(target,index)
glGetProgramLocalParameterdvARB_s(target,index,params)
glGetProgramLocalParameterfvARB_c(target,index,params)
glGetProgramLocalParameterfvARB_p(target,index)
glGetProgramLocalParameterfvARB_s(target,index,params)
glGetProgramStringARB_c(target,pname,string)
glGetProgramStringARB_p(target,pname=GL_PROGRAM_STRING_ARB)
glGetProgramStringARB_s(target,pname,string)
glGetProgramivARB_c(target,pname,params)
glGetProgramivARB_p(target,pname)
glGetProgramivARB_s(target,pname,params)
glGetRenderbufferParameterivEXT_c(target,pname,params)
glGetRenderbufferParameterivEXT_s(target,pname,params)
glGetShaderSourceARB_c(obj, maxLength, length, source)
glGetShaderSourceARB_p(obj)
glGetString(name)
glGetTexEnvfv_c(target, pname, params)
glGetTexEnvfv_p(target, pname)
glGetTexEnvfv_s(target, pname, params)
glGetTexEnviv_c(target, pname, params)
glGetTexEnviv_p(target, pname)
glGetTexEnviv_s(target, pname, params)
glGetTexGendv_c(coord, pname, params)
glGetTexGendv_p(coord, pname)
glGetTexGendv_s(coord, pname, params)
glGetTexGenfv_c(coord, pname, params)
glGetTexGenfv_p(coord, pname)
glGetTexGenfv_s(coord, pname, params)
glGetTexGeniv_c(coord, pname, params)
glGetTexGeniv_p(coord, pname)
glGetTexGeniv_s(coord, pname, params)
glGetTexImage_c(target, level, format, type, pixels)
glGetTexImage_p(target, level, format, type)
glGetTexImage_s(target, level, format, type, pixels)
glGetTexLevelParameterfv_c(target, level, pname, params)
glGetTexLevelParameterfv_p(target, level, pname)
glGetTexLevelParameterfv_s(target, level, pname, params)
glGetTexLevelParameteriv_c(target, level, pname, params)
glGetTexLevelParameteriv_p(target, level, pname)
glGetTexLevelParameteriv_s(target, level, pname, params)
glGetTexParameterfv_c(target, pname, params)
glGetTexParameterfv_p(target, pname)
glGetTexParameterfv_s(target, pname, params)
glGetTexParameteriv_c(target, pname, params)
glGetTexParameteriv_p(target, pname)
glGetTexParameteriv_s(target, pname, params)
glGetUniformLocationARB_c(programObj, name)
glGetUniformLocationARB_p(programObj, ...)
glGetUniformfvARB_c(programObj, location, params)
glGetUniformfvARB_p(programObj, location, count=1)
glGetUniformivARB_c(programObj, location, params)
glGetUniformivARB_p(programObj, location, count=1)
glGetVertexAttribPointervARB_c(index,pname,pointer)
glGetVertexAttribPointervARB_p(index,pname)
glGetVertexAttribdvARB_c(index,pname,params)
glGetVertexAttribdvARB_p(index,pname)
glGetVertexAttribdvARB_s(index,pname,params)
glGetVertexAttribfvARB_c(index,pname,params)
glGetVertexAttribfvARB_p(index,pname)
glGetVertexAttribfvARB_s(index,pname,params)
glGetVertexAttribivARB_c(index,pname,params)
glGetVertexAttribivARB_p(index,pname)
glGetVertexAttribivARB_s(index,pname,params)
glHint(target, mode)
glIndexMask(mask)
glIndexPointerEXT_c(type, stride, count, pointer)
glIndexPointerEXT_p(oga)
glIndexPointerEXT_s(type, stride, count, pointer)
glIndexPointer_c(type, stride, pointer)
glIndexPointer_p(oga)
glIndexPointer_s(type, stride, pointer)
glIndexd(c)
glIndexi(c)
glInitNames()
glInterleavedArrays_c(format, stride, pointer)
glIsBufferARB(buffer)
glIsEnabled(cap)
glIsFramebufferEXT(framebuffer)
glIsList(list)
glIsProgramARB(program)
glIsRenderbufferEXT(renderbuffer)
glIsTexture(list)
glIsTextureEXT(list)
glLightModelf(pname, param)
glLightModelfv_c(pname, params)
glLightModelfv_p(pname, ...)
glLightModelfv_s(pname, params)
glLightModeli(pname, param)
glLightModeliv_c(pname, params)
glLightModeliv_p(pname, ...)
glLightModeliv_s(pname, params)
glLightf(light, pname, param)
glLightfv_c(light, pname, params)
glLightfv_p(light, pname, ...)
glLightfv_s(light, pname, params)
glLighti(light, pname, param)
glLightiv_c(light, pname, params)
glLightiv_p(light, pname, ...)
glLightiv_s(light, pname, params)
glLineStipple(factor, pattern)
glLineWidth(width)
glLinkProgramARB(programObj)
glListBase(base)
glLoadIdentity()
glLoadMatrixd_c(m)
glLoadMatrixd_p(...)
glLoadMatrixd_s(m)
glLoadMatrixf_c(m)
glLoadMatrixf_p(...)
glLoadMatrixf_s(m)
glLoadName(name)
glLogicOp(opcode)
glMap1d_c(target, u1, u2, stride, order, points)
glMap1d_p(target, u1, u2, ...)
glMap1d_s(target, u1, u2, stride, order, points)
glMap1f_c(target, u1, u2, stride, order, points)
glMap1f_p(target, u1, u2, ...)
glMap1f_s(target, u1, u2, stride, order, points)
glMap2d_c(target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points)
glMap2d_p(target, u1, u2, uorder, v1, v2, ...)
glMap2d_s(target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points)
glMap2f_c(target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points)
glMap2f_p(target, u1, u2, uorder, v1, v2, ...)
glMap2f_s(target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points)
glMapBufferARB_c(target,access)
glMapBufferARB_p(target,access,...)
glMapGrid1d(un, u1, u2)
glMapGrid1f(un, u1, u2)
glMapGrid2d(un, u1, u2, vn, v1, v2)
glMapGrid2f(un, u1, u2, vn, v1, v2)
glMaterialf(face, pname, param)
glMaterialfv_c(face, pname, param)
glMaterialfv_p(face, pname, ...)
glMaterialfv_s(face, pname, param)
glMateriali(face, pname, param)
glMaterialiv_c(face, pname, param)
glMaterialiv_p(face, pname, ...)
glMaterialiv_s(face, pname, param)
glMatrixMode(mode)
glMultMatrixd_p(...)
glMultMatrixf_p(...)
glMultiTexCoord1dARB(target,s)
glMultiTexCoord1dvARB_c(target,v)
glMultiTexCoord1dvARB_p(target,s)
glMultiTexCoord1dvARB_s(target,v)
glMultiTexCoord1fARB(target,s)
glMultiTexCoord1fvARB_c(target,v)
glMultiTexCoord1fvARB_p(target,s)
glMultiTexCoord1fvARB_s(target,v)
glMultiTexCoord1iARB(target,s)
glMultiTexCoord1ivARB_c(target,v)
glMultiTexCoord1ivARB_p(target,s)
glMultiTexCoord1ivARB_s(target,v)
glMultiTexCoord1sARB(target,s)
glMultiTexCoord1svARB_c(target,v)
glMultiTexCoord1svARB_p(target,s)
glMultiTexCoord1svARB_s(target,v)
glMultiTexCoord2dARB(target,s,t)
glMultiTexCoord2dvARB_c(target,v)
glMultiTexCoord2dvARB_p(target,s,t)
glMultiTexCoord2dvARB_s(target,v)
glMultiTexCoord2fARB(target,s,t)
glMultiTexCoord2fvARB_c(target,v)
glMultiTexCoord2fvARB_p(target,s,t)
glMultiTexCoord2fvARB_s(target,v)
glMultiTexCoord2iARB(target,s,t)
glMultiTexCoord2ivARB_c(target,v)
glMultiTexCoord2ivARB_p(target,s,t)
glMultiTexCoord2ivARB_s(target,v)
glMultiTexCoord2sARB(target,s,t)
glMultiTexCoord2svARB_c(target,v)
glMultiTexCoord2svARB_p(target,s,t)
glMultiTexCoord2svARB_s(target,v)
glMultiTexCoord3dARB(target,s,t,r)
glMultiTexCoord3dvARB_c(target,v)
glMultiTexCoord3dvARB_p(target,s,t,r)
glMultiTexCoord3dvARB_s(target,v)
glMultiTexCoord3fARB(target,s,t,r)
glMultiTexCoord3fvARB_c(target,v)
glMultiTexCoord3fvARB_p(target,s,t,r)
glMultiTexCoord3fvARB_s(target,v)
glMultiTexCoord3iARB(target,s,t,r)
glMultiTexCoord3ivARB_c(target,v)
glMultiTexCoord3ivARB_p(target,s,t,r)
glMultiTexCoord3ivARB_s(target,v)
glMultiTexCoord3sARB(target,s,t,r)
glMultiTexCoord3svARB_c(target,v)
glMultiTexCoord3svARB_p(target,s,t,r)
glMultiTexCoord3svARB_s(target,v)
glMultiTexCoord4dARB(target,s,t,r,q)
glMultiTexCoord4dvARB_c(target,v)
glMultiTexCoord4dvARB_p(target,s,t,r,q)
glMultiTexCoord4dvARB_s(target,v)
glMultiTexCoord4fARB(target,s,t,r,q)
glMultiTexCoord4fvARB_c(target,v)
glMultiTexCoord4fvARB_p(target,s,t,r,q)
glMultiTexCoord4fvARB_s(target,v)
glMultiTexCoord4iARB(target,s,t,r,q)
glMultiTexCoord4ivARB_c(target,v)
glMultiTexCoord4ivARB_p(target,s,t,r,q)
glMultiTexCoord4ivARB_s(target,v)
glMultiTexCoord4sARB(target,s,t,r,q)
glMultiTexCoord4svARB_c(target,v)
glMultiTexCoord4svARB_p(target,s,t,r,q)
glMultiTexCoord4svARB_s(target,v)
glNewList(list, mode)
glNormal3b(nx, ny, nz)
glNormal3bv_c(v)
glNormal3bv_p(nx, ny, nz)
glNormal3bv_s(v)
glNormal3d(nx, ny, nz)
glNormal3dv_c(v)
glNormal3dv_p(nx, ny, nz)
glNormal3dv_s(v)
glNormal3f(nx, ny, nz)
glNormal3fv_c(v)
glNormal3fv_p(nx, ny, nz)
glNormal3fv_s(v)
glNormal3i(nx, ny, nz)
glNormal3iv_c(v)
glNormal3iv_p(nx, ny, nz)
glNormal3iv_s(v)
glNormal3s(nx, ny, nz)
glNormal3sv_c(v)
glNormal3sv_p(nx, ny, nz)
glNormal3sv_s(v)
glNormalPointerEXT_c(type, stride, count, pointer)
glNormalPointerEXT_p(oga)
glNormalPointerEXT_s(type, stride, count, pointer)
glNormalPointer_c(type, stride, pointer)
glNormalPointer_p(oga)
glNormalPointer_s(type, stride, pointer)
glOrtho(left, right, bottom, top, zNear, zFar)
glPassThrough(token)
glPixelMapfv_c(map, mapsize, values)
glPixelMapfv_p(map, ...)
glPixelMapfv_s(map, mapsize, values)
glPixelMapuiv_c(map, mapsize, values)
glPixelMapuiv_p(map, ...)
glPixelMapuiv_s(map, mapsize, values)
glPixelMapusv_c(map, mapsize, values)
glPixelMapusv_p(map, ...)
glPixelMapusv_s(map, mapsize, values)
glPixelStoref(pname, param)
glPixelStorei(pname, param)
glPixelTransferf(pname, param)
glPixelTransferi(pname, param)
glPixelZoom(xfactor, yfactor)
glPointParameterfARB(pname,param)
glPointParameterfvARB_c(pname,params)
glPointParameterfvARB_p(pname, ...)
glPointParameterfvARB_s(pname,params)
glPointSize(size)
glPolygonMode(face, mode)
glPolygonOffset(factor, units)
glPolygonOffsetEXT(factor, bias)
glPolygonStipple_c(mask)
glPolygonStipple_p(...)
glPolygonStipple_s(mask)
glPopAttrib()
glPopClientAttrib()
glPopMatrix()
glPopName()
glPrioritizeTexturesEXT_p(...)
glPrioritizeTextures_c(n, textures, priorities)
glPrioritizeTextures_p(...)
glPrioritizeTextures_s(n, textures, priorities)
glProgramEnvParameter4dARB(target,index,x,y,z,w)
glProgramEnvParameter4dvARB_c(target,index,v)
glProgramEnvParameter4dvARB_p(target,index,x,y,z,w)
glProgramEnvParameter4dvARB_s(target,index,v)
glProgramEnvParameter4fARB(target,index,x,y,z,w)
glProgramEnvParameter4fvARB_c(target,index,v)
glProgramEnvParameter4fvARB_p(target,index,x,y,z,w)
glProgramEnvParameter4fvARB_s(target,index,v)
glProgramLocalParameter4dARB(target,index,x,y,z,w)
glProgramLocalParameter4dvARB_c(target,index,v)
glProgramLocalParameter4dvARB_p(target,index,x,y,z,w)
glProgramLocalParameter4dvARB_s(target,index,v)
glProgramLocalParameter4fARB(target,index,x,y,z,w)
glProgramLocalParameter4fvARB_c(target,index,v)
glProgramLocalParameter4fvARB_p(target,index,x,y,z,w)
glProgramLocalParameter4fvARB_s(target,index,v)
glProgramStringARB_c(target,format,len,string)
glProgramStringARB_p(target,string)
glProgramStringARB_s(target,format,len,string)
glPushAttrib(mask)
glPushClientAttrib(mask)
glPushMatrix()
glPushName(name)
glRasterPos2d(x, y)
glRasterPos2dv_c(v)
glRasterPos2dv_p(x, y)
glRasterPos2dv_s(v)
glRasterPos2f(x, y)
glRasterPos2fv_c(v)
glRasterPos2fv_p(x, y)
glRasterPos2fv_s(v)
glRasterPos2i(x, y)
glRasterPos2iv_c(v)
glRasterPos2iv_p(x, y)
glRasterPos2iv_s(v)
glRasterPos2s(x, y)
glRasterPos2sv_c(v)
glRasterPos2sv_p(x, y)
glRasterPos2sv_s(v)
glRasterPos3d(x, y, z)
glRasterPos3dv_c(v)
glRasterPos3dv_p(x, y, z)
glRasterPos3dv_s(v)
glRasterPos3f(x, y, z)
glRasterPos3fv_c(v)
glRasterPos3fv_p(x, y, z)
glRasterPos3fv_s(v)
glRasterPos3i(x, y, z)
glRasterPos3iv_c(v)
glRasterPos3iv_p(x, y, z)
glRasterPos3iv_s(v)
glRasterPos3s(x, y, z)
glRasterPos3sv_c(v)
glRasterPos3sv_p(x, y, z)
glRasterPos3sv_s(v)
glRasterPos4d(x, y, z, w)
glRasterPos4dv_c(v)
glRasterPos4dv_p(x, y, z, w)
glRasterPos4dv_s(v)
glRasterPos4f(x, y, z, w)
glRasterPos4fv_c(v)
glRasterPos4fv_p(x, y, z, w)
glRasterPos4fv_s(v)
glRasterPos4i(x, y, z, w)
glRasterPos4iv_c(v)
glRasterPos4iv_p(x, y, z, w)
glRasterPos4iv_s(v)
glRasterPos4s(x, y, z, w)
glRasterPos4sv_c(v)
glRasterPos4sv_p(x, y, z, w)
glRasterPos4sv_s(v)
glReadBuffer(mode)
glReadPixels_c(x, y, width, height, format, type, pixels)
glReadPixels_p(x, y, width, height, format, type)
glReadPixels_s(x, y, width, height, format, type, pixels)
glRectd(x1, y1, x2, y2)
glRectdv_c(v1, v2)
glRectdv_s(v1, v2)
glRectf(x1, y1, x2, y2)
glRectfv_c(v1, v2)
glRectfv_s(v1, v2)
glRecti(x1, y1, x2, y2)
glRectiv_c(v1, v2)
glRectiv_s(v1, v2)
glRects(x1, y1, x2, y2)
glRectsv_c(v1, v2)
glRectsv_s(v1, v2)
glRenderMode(mode)
glRenderbufferStorageEXT(target,internalformat,width,height)
glResizeBuffersMESA()
glRotated(angle, x, y, z)
glRotatef(angle, x, y, z)
glSampleCoverageARB(value,invert)
glScaled(x, y, z)
glScalef(x, y, z)
glScissor(x, y, width, height)
glSelectBuffer_c(size, list)
glShadeModel(mode)
glShaderSourceARB_c(shaderObj, count, string, length)
glShaderSourceARB_p(shaderObj, ...)
glStencilFunc(func, ref, mask)
glStencilMask(mask)
glStencilOp(fail, zfail, zpass)
glTexCoord1d(s)
glTexCoord1dv_c(v)
glTexCoord1dv_p(s)
glTexCoord1dv_s(v)
glTexCoord1f(s)
glTexCoord1fv_c(v)
glTexCoord1fv_p(s)
glTexCoord1fv_s(v)
glTexCoord1i(s)
glTexCoord1iv_c(v)
glTexCoord1iv_p(s)
glTexCoord1iv_s(v)
glTexCoord1s(s)
glTexCoord1sv_c(v)
glTexCoord1sv_p(s)
glTexCoord1sv_s(v)
glTexCoord2d(s, t)
glTexCoord2dv_c(v)
glTexCoord2dv_p(s, t)
glTexCoord2dv_s(v)
glTexCoord2f(s, t)
glTexCoord2fv_c(v)
glTexCoord2fv_p(s, t)
glTexCoord2fv_s(v)
glTexCoord2i(s, t)
glTexCoord2iv_c(v)
glTexCoord2iv_p(s, t)
glTexCoord2iv_s(v)
glTexCoord2s(s, t)
glTexCoord2sv_c(v)
glTexCoord2sv_p(s, t)
glTexCoord2sv_s(v)
glTexCoord3d(s, t, r)
glTexCoord3dv_c(v)
glTexCoord3dv_p(s, t, r)
glTexCoord3dv_s(v)
glTexCoord3f(s, t, r)
glTexCoord3fv_c(v)
glTexCoord3fv_p(s, t, r)
glTexCoord3fv_s(v)
glTexCoord3i(s, t, r)
glTexCoord3iv_c(v)
glTexCoord3iv_p(s, t, r)
glTexCoord3iv_s(v)
glTexCoord3s(s, t, r)
glTexCoord3sv_c(v)
glTexCoord3sv_p(s, t, r)
glTexCoord3sv_s(v)
glTexCoord4d(s, t, r, q)
glTexCoord4dv_c(v)
glTexCoord4dv_p(s, t, r, q)
glTexCoord4dv_s(v)
glTexCoord4f(s, t, r, q)
glTexCoord4fv_c(v)
glTexCoord4fv_p(s, t, r, q)
glTexCoord4fv_s(v)
glTexCoord4i(s, t, r, q)
glTexCoord4iv_c(v)
glTexCoord4iv_p(s, t, r, q)
glTexCoord4iv_s(v)
glTexCoord4s(s, t, r, q)
glTexCoord4sv_c(v)
glTexCoord4sv_p(s, t, r, q)
glTexCoord4sv_s(v)
glTexCoordPointerEXT_c(size, type, stride, count, pointer)
glTexCoordPointerEXT_p(size, oga)
glTexCoordPointerEXT_s(size, type, stride, count, pointer)
glTexCoordPointer_c(size, type, stride, pointer)
glTexCoordPointer_p(size, oga)
glTexCoordPointer_s(size, type, stride, pointer)
glTexEnvf(target, pname, param)
glTexEnvfv_p(target, pname, ...)
glTexEnvfv_s(target, pname, params)
glTexEnvi(target, pname, param)
glTexEnviv_p(target, pname, ...)
glTexEnviv_s(target, pname, params)
glTexGend(Coord, pname, param)
glTexGendv_c(Coord, pname, params)
glTexGendv_p(Coord, pname, ...)
glTexGendv_s(Coord, pname, params)
glTexGenf(Coord, pname, param)
glTexGenfv_c(Coord, pname, params)
glTexGenfv_p(Coord, pname, ...)
glTexGenfv_s(Coord, pname, params)
glTexGeni(Coord, pname, param)
glTexGeniv_c(Coord, pname, params)
glTexGeniv_p(Coord, pname, ...)
glTexGeniv_s(Coord, pname, params)
glTexImage1D_c(target, level, internalformat, width, border, format, type, pixels)
glTexImage1D_p(target, level, internalformat, width, border, format, type, ...)
glTexImage1D_s(target, level, internalformat, width, border, format, type, pixels)
glTexImage2D_c(target, level, internalformat, width, height, border, format, type, pixels)
glTexImage2D_p(target, level, internalformat, width, height, border, format, type, ...)
glTexImage2D_s(target, level, internalformat, width, height, border, format, type, pixels)
glTexImage3DEXT_c(target, level, internalformat, width, height, depth, border, format, type, pixels)
glTexImage3DEXT_p(target, level, internalformat, width, height, depth, border, format, type, ...)
glTexImage3DEXT_s(target, level, internalformat, width, height, depth, border, format, type, pixels)
glTexImage3D_c(target, level, internalformat, width, height, depth, border, format, type, pixels)
glTexImage3D_p(target, level, internalformat, width, height, depth, border, format, type, ...)
glTexImage3D_s(target, level, internalformat, width, height, depth, border, format, type, pixels)
glTexParameterf(target, pname, param)
glTexParameterfv_c(target, pname, params)
glTexParameterfv_p(target, pname, ...)
glTexParameterfv_s(target, pname, params)
glTexParameteri(target, pname, param)
glTexParameteriv_c(target, pname, params)
glTexParameteriv_p(target, pname, ...)
glTexParameteriv_s(target, pname, params)
glTexSubImage1DEXT_c(target, level, xoffset, width, format, type, pixels)
glTexSubImage1DEXT_p(target, level, xoffset, width, format, type, ...)
glTexSubImage1DEXT_s(target, level, xoffset, width, format, type, pixels)
glTexSubImage1D_c(target, level, xoffset, width, border, format, type, pixels)
glTexSubImage1D_p(target, level, xoffset, width, format, type, ...)
glTexSubImage1D_s(target, level, xoffset, width, format, type, pixels)
glTexSubImage2DEXT_c(target, level, xoffset, yoffset, width, height, format, type, pixels)
glTexSubImage2DEXT_p(target, level, xoffset, yoffset, width, height, format, type, ...)
glTexSubImage2DEXT_s(target, level, xoffset, yoffset, width, height, format, type, pixels)
glTexSubImage2D_c(target, level, xoffset, yoffset, width, height, format, type, pixels)
glTexSubImage2D_p(target, level, xoffset, yoffset, width, height, format, type, ...)
glTexSubImage2D_s(target, level, xoffset, yoffset, width, height, format, type, pixels)
glTexSubImage3DEXT_c(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels)
glTexSubImage3DEXT_p(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, ...)
glTexSubImage3DEXT_s(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels)
glTexSubImage3D_c(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels)
glTexSubImage3D_p(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, ...)
glTexSubImage3D_s(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels)
glTranslated(x, y, z)
glTranslatef(x, y, z)
glUniform1fARB(location, v0)
glUniform1fvARB_c(location, count, value)
glUniform1fvARB_p(location, ...)
glUniform1fvARB_s(location, count, value)
glUniform1iARB(location, v0)
glUniform1ivARB_c(location, count, value)
glUniform1ivARB_p(location, ...)
glUniform1ivARB_s(location, count, value)
glUniform2fARB(location, v0, v1)
glUniform2fvARB_c(location, count, value)
glUniform2fvARB_p(location, ...)
glUniform2fvARB_s(location, count, value)
glUniform2iARB(location, v0, v1)
glUniform2ivARB_c(location, count, value)
glUniform2ivARB_p(location, ...)
glUniform2ivARB_s(location, count, value)
glUniform3fARB(location, v0, v1, v2)
glUniform3fvARB_c(location, count, value)
glUniform3fvARB_p(location, ...)
glUniform3fvARB_s(location, count, value)
glUniform3iARB(location, v0, v1, v2)
glUniform3ivARB_c(location, count, value)
glUniform3ivARB_p(location, ...)
glUniform3ivARB_s(location, count, value)
glUniform4fARB(location, v0, v1, v2, v3)
glUniform4fvARB_c(location, count, value)
glUniform4fvARB_p(location, ...)
glUniform4fvARB_s(location, count, value)
glUniform4iARB(location, v0, v1, v2, v3)
glUniform4ivARB_c(location, count, value)
glUniform4ivARB_p(location, ...)
glUniform4ivARB_s(location, count, value)
glUniformMatrix2fvARB_c(location, count, transpose, value)
glUniformMatrix2fvARB_p(location, transpose, ...)
glUniformMatrix2fvARB_s(location, count, transpose, value)
glUniformMatrix3fvARB_c(location, count, transpose, value)
glUniformMatrix3fvARB_p(location, transpose, ...)
glUniformMatrix3fvARB_s(location, count, transpose, value)
glUniformMatrix4fvARB_c(location, count, transpose, value)
glUniformMatrix4fvARB_p(location, transpose, ...)
glUniformMatrix4fvARB_s(location, count, transpose, value)
glUnmapBufferARB(target)
glUseProgramObjectARB(programObj)
glValidateProgramARB(programObj)
glVertex2d(x, y)
glVertex2dv_c(v)
glVertex2dv_p(x, y)
glVertex2dv_s(v)
glVertex2f(x, y)
glVertex2fv_c(v)
glVertex2fv_p(x, y)
glVertex2fv_s(v)
glVertex2i(x, y)
glVertex2iv_c(v)
glVertex2iv_p(x, y)
glVertex2iv_s(v)
glVertex2s(x, y)
glVertex2sv_c(v)
glVertex2sv_p(x, y)
glVertex2sv_s(v)
glVertex3d(x, y, z)
glVertex3dv_c(v)
glVertex3dv_p(x, y, z)
glVertex3dv_s(v)
glVertex3f(x, y, z)
glVertex3fv_c(v)
glVertex3fv_p(x, y, z)
glVertex3fv_s(v)
glVertex3i(x, y, z)
glVertex3iv_c(v)
glVertex3iv_p(x, y, z)
glVertex3iv_s(v)
glVertex3s(x, y, z)
glVertex3sv_c(v)
glVertex3sv_p(x, y, z)
glVertex3sv_s(v)
glVertex4d(x, y, z, w)
glVertex4dv_c(v)
glVertex4dv_p(x, y, z, w)
glVertex4dv_s(v)
glVertex4f(x, y, z, w)
glVertex4fv_c(v)
glVertex4fv_p(x, y, z, w)
glVertex4fv_s(v)
glVertex4i(x, y, z, w)
glVertex4iv_c(v)
glVertex4iv_p(x, y, z, w)
glVertex4iv_s(v)
glVertex4s(x, y, z, w)
glVertex4sv_c(v)
glVertex4sv_p(x, y, z, w)
glVertex4sv_s(v)
glVertexAttrib1dARB(index,x)
glVertexAttrib1dvARB_c(index,v)
glVertexAttrib1dvARB_p(index,x)
glVertexAttrib1dvARB_s(index,v)
glVertexAttrib1fARB(index,x)
glVertexAttrib1sARB(index,x)
glVertexAttrib1svARB_c(index,v)
glVertexAttrib1svARB_p(index,x)
glVertexAttrib1svARB_s(index,v)
glVertexAttrib2dARB(index,x,y)
glVertexAttrib2dvARB_c(index,v)
glVertexAttrib2dvARB_p(index,x,y)
glVertexAttrib2dvARB_s(index,v)
glVertexAttrib2fARB(index,x,y)
glVertexAttrib2sARB(index,x,y)
glVertexAttrib2svARB_c(index,v)
glVertexAttrib2svARB_p(index,x,y)
glVertexAttrib2svARB_s(index,v)
glVertexAttrib3dARB(index,x,y,z)
glVertexAttrib3dvARB_c(index,v)
glVertexAttrib3dvARB_p(index,x,y,z)
glVertexAttrib3dvARB_s(index,v)
glVertexAttrib3fARB(index,x,y,z)
glVertexAttrib3fvARB_c(index,v)
glVertexAttrib3fvARB_p(index,x,y,z)
glVertexAttrib3fvARB_s(index,v)
glVertexAttrib3sARB(index,x,y,z)
glVertexAttrib3svARB_c(index,v)
glVertexAttrib3svARB_p(index,x,y,z)
glVertexAttrib3svARB_s(index,v)
glVertexAttrib4NbvARB_c(index,v)
glVertexAttrib4NbvARB_p(index,x,y,z,w)
glVertexAttrib4NbvARB_s(index,v)
glVertexAttrib4NivARB_c(index,v)
glVertexAttrib4NivARB_p(index,x,y,z,w)
glVertexAttrib4NivARB_s(index,v)
glVertexAttrib4NsvARB_c(index,v)
glVertexAttrib4NsvARB_p(index,x,y,z,w)
glVertexAttrib4NsvARB_s(index,v)
glVertexAttrib4NubARB(index,x,y,z,w)
glVertexAttrib4NubvARB_c(index,v)
glVertexAttrib4NubvARB_p(index,x,y,z,w)
glVertexAttrib4NubvARB_s(index,v)
glVertexAttrib4NuivARB_c(index,v)
glVertexAttrib4NuivARB_p(index,x,y,z,w)
glVertexAttrib4NuivARB_s(index,v)
glVertexAttrib4NusvARB_c(index,v)
glVertexAttrib4NusvARB_p(index,x,y,z,w)
glVertexAttrib4NusvARB_s(index,v)
glVertexAttrib4bvARB_c(index,v)
glVertexAttrib4bvARB_p(index,x,y,z,w)
glVertexAttrib4bvARB_s(index,v)
glVertexAttrib4dARB(index,x,y,z,w)
glVertexAttrib4dvARB_c(index,v)
glVertexAttrib4dvARB_p(index,x,y,z,w)
glVertexAttrib4dvARB_s(index,v)
glVertexAttrib4fARB(index,x,y,z,w)
glVertexAttrib4fvARB_c(index,v)
glVertexAttrib4fvARB_p(index,x,y,z,w)
glVertexAttrib4fvARB_s(index,v)
glVertexAttrib4ivARB_c(index,v)
glVertexAttrib4ivARB_p(index,x,y,z,w)
glVertexAttrib4ivARB_s(index,v)
glVertexAttrib4sARB(index,x,y,z,w)
glVertexAttrib4svARB_c(index,v)
glVertexAttrib4svARB_p(index,x,y,z,w)
glVertexAttrib4svARB_s(index,v)
glVertexAttrib4ubvARB_c(index,v)
glVertexAttrib4ubvARB_p(index,x,y,z,w)
glVertexAttrib4ubvARB_s(index,v)
glVertexAttrib4uivARB_c(index,v)
glVertexAttrib4uivARB_p(index,x,y,z,w)
glVertexAttrib4uivARB_s(index,v)
glVertexAttrib4usvARB_c(index,v)
glVertexAttrib4usvARB_p(index,x,y,z,w)
glVertexAttrib4usvARB_s(index,v)
glVertexAttribPointerARB_c(index,size,type,normalized,stride,pointer)
glVertexAttribPointerARB_p(index,type,normalized,stride,...)
glVertexPointerEXT_c(size, type, stride, count, pointer)
glVertexPointerEXT_p(size, oga)
glVertexPointerEXT_s(size, type, stride, count, pointer)
glVertexPointer_c(size, type, stride, pointer)
glVertexPointer_p(size, oga)
glVertexPointer_s(size, type, stride, pointer)
glViewport(x, y, width, height)
glWindowPos2dMESA(x, y)
glWindowPos2iMESA(x, y)
glWindowPos3dMESA(x, y, z)
glWindowPos3iMESA(x, y, z)
glWindowPos4dMESA(x, y, z, w)
glWindowPos4iMESA(x, y, z, w)
glXSwapBuffers(w=win,d=dpy)

glpDisplay(name)
glpMoveResizeWindow(x, y, width, height, w=win, d=dpy)
glpMoveWindow(x, y, w=win, d=dpy)
glpPrintString(base,str)
glpReadTex(file)
glpResizeWindow(width, height, w=win, d=dpy)
glpSetDebug(flag)
glpXQueryPointer(w=win,d=dpy)
glpcOpenWindow(x,y,w,h,pw,event_mask,steal, ...)

gluBeginCurve(nurb)
gluBeginPolygon(tess)
gluBeginSurface(nurb)
gluBeginTrim(nurb)
gluBuild1DMipmaps_c(target, internalformat, width, format, type, data)
gluBuild1DMipmaps_s(target, internalformat, width, format, type, data)
gluBuild2DMipmaps_c(target, internalformat, width, height, format, type, data)
gluBuild2DMipmaps_s(target, internalformat, width, height, format, type, data)
gluCylinder(quad, base, top, height, slices, stacks)
gluDeleteNurbsRenderer(nurb)
gluDeleteQuadric(quad)
gluDeleteTess(tess)
gluDisk(quad, inner, outer, slices, loops)
gluEndCurve(nurb)
gluEndPolygon(tess)
gluEndSurface(nurb)
gluEndTrim(nurb)
gluGetNurbsProperty_p(nurb, property)
gluGetTessProperty_p(tess, property)
gluLoadSamplingMatrices_p(nurb, m1,m2,m3,m4,m5,m6,m7,m8,m9,m10,m11,m12,m13,m14,m15,m16, o1,o2,o3,o4,o5,o6,o7,o8,o9,o10,o11,o12,o13,o14,o15,o16, v1,v2,v3,v4)
gluLookAt(eyeX, eyeY, eyeZ, centerX, centerY, centerZ, upX, upY, upZ)
gluNewNurbsRenderer()
gluNewQuadric()
gluNewTess(...)
gluNextContour(tess, type)
gluNurbsCurve_c(nurb, nknots, knot, stride, ctlarray, order, type)
gluNurbsProperty(nurb, property, value)
gluNurbsSurface_c(nurb, sknot_count, sknot, tknot_count, tknot, s_stride, t_stride, ctrlarray, sorder, torder, type)
gluOrtho2D(left, right, bottom, top)
gluPartialDisk(quad, inner, outer, slices, loops, start, sweep)
gluPerspective(fovy, aspect, zNear, zFar)
gluPickMatrix_p(x, y, delX, delY, m1,m2,m3,m4)
gluProject_p(objx, objy, objz, m1,m2,m3,m4,m5,m6,m7,m8,m9,m10,m11,m12,m13,m14,m15,m16, o1,o2,o3,o4,o5,o6,o7,o8,o9,o10,o11,o12,o13,o14,o15,o16, v1,v2,v3,v4)
gluPwlCurve_c(nurb, count, data, stride, type)
gluQuadricDrawStyle(quad, draw)
gluQuadricNormals(quad, normal)
gluQuadricOrientation(quad, orientation)
gluQuadricTexture(quad, texture)
gluScaleImage_s(format, wIn, hIn, typeIn, dataIn, wOut, hOut, typeOut, dataOut)
gluSphere(quad, radius, slices, stacks)
gluTessBeginContour(tess)
gluTessBeginPolygon(tess, ...)
gluTessCallback(tess, which, ...)
gluTessEndContour(tess)
gluTessEndPolygon(tess)
gluTessNormal(tess, valueX, valueY, valueZ)
gluTessProperty(tess, which, data)
gluTessVertex_p(tess, x, y, z, ...)
gluUnProject_p(winx,winy,winz, m1,m2,m3,m4,m5,m6,m7,m8,m9,m10,m11,m12,m13,m14,m15,m16, o1,o2,o3,o4,o5,o6,o7,o8,o9,o10,o11,o12,o13,o14,o15,o16, v1,v2,v3,v4)

glutAddMenuEntry(name, value)
glutAddSubMenu(name, menu)
glutAttachMenu(button)
glutBitmapCharacter(font, character)
glutBitmapString(font, string)
glutButtonBoxFunc(handler=0, ...)
glutChangeToMenuEntry(entry, name, value)
glutChangeToSubMenu(entry, name, menu)
glutCloseFunc(handler=0, ...)
glutCopyColormap(win)
glutDestroyMenu(menu)
glutDestroyWindow(win)
glutDetachMenu(button)
glutDialsFunc(handler=0, ...)
glutDisplayFunc(handler=0, ...)
glutEntryFunc(handler=0, ...)
glutEstablishOverlay()
glutForceJoystickFunc()
glutFullScreen()
glutGameModeString(string)
glutGetColor(cell, component)
glutHideOverlay()
glutHideWindow()
glutIconifyWindow()
glutIdleFunc(handler=0, ...)
glutIgnoreKeyRepeat(ignore)
glutInit()
glutInitDisplayMode(mode)
glutInitDisplayString(string)
glutInitWindowPosition(x, y)
glutInitWindowSize(width, height)
glutKeyboardFunc(handler=0, ...)
glutKeyboardUpFunc(handler=0, ...)
glutLeaveGameMode()
glutLeaveMainLoop()
glutMainLoop()
glutMainLoopEvent()
glutMenuDestroyFunc(handler=0, ...)
glutMenuStateFunc(handler=0, ...)
glutMenuStatusFunc(handler=0, ...)
glutMotionFunc(handler=0, ...)
glutMouseFunc(handler=0, ...)
glutMouseWheelFunc(handler=0, ...)
glutOverlayDisplayFunc(handler=0, ...)
glutPassiveMotionFunc(handler=0, ...)
glutPopWindow()
glutPositionWindow(x, y)
glutPostOverlayRedisplay()
glutPostRedisplay()
glutPostWindowOverlayRedisplay(windowID)
glutPostWindowRedisplay(windowID)
glutPushWindow()
glutRemoveMenuItem(entry)
glutRemoveOverlay()
glutReportErrors()
glutReshapeFunc(handler=0, ...)
glutReshapeWindow(width, height)
glutSetColor(cell, red, green, blue)
glutSetCursor(cursor)
glutSetIconTitle(title)
glutSetKeyRepeat(repeatMode)
glutSetMenu(menu)
glutSetOption(option_flag, value)
glutSetWindow(win)
glutSetWindowTitle(title)
glutShowOverlay()
glutShowWindow()
glutSolidCone(base, height, slices, stacks)
glutSolidCube(size)
glutSolidCylinder(radius, height, slices, stacks)
glutSolidDodecahedron()
glutSolidIcosahedron()
glutSolidOctahedron()
glutSolidRhombicDodecahedron()
glutSolidSphere(radius, slices, stacks)
glutSolidTeapot(size)
glutSolidTetrahedron()
glutSolidTorus(innerRadius, outerRadius, nsides, rings)
glutSpaceballButtonFunc(handler=0, ...)
glutSpaceballMotionFunc(handler=0, ...)
glutSpaceballRotateFunc(handler=0, ...)
glutSpecialFunc(handler=0, ...)
glutSpecialUpFunc(handler=0, ...)
glutStrokeCharacter(font, character)
glutStrokeHeight(font)
glutStrokeLength(font, string)
glutStrokeString(font, string)
glutSwapBuffers()
glutTabletButtonFunc(handler=0, ...)
glutTabletMotionFunc(handler=0, ...)
glutTimerFunc(msecs, handler=0, ...)
glutUseLayer(layer)
glutVisibilityFunc(handler=0, ...)
glutWarpPointer(x, y)
glutWindowStatusFunc(handler=0, ...)
glutWireCone(base, height, slices, stacks)
glutWireCube(size)
glutWireCylinder(radius, height, slices, stacks)
glutWireDodecahedron()
glutWireIcosahedron()
glutWireOctahedron()
glutWireRhombicDodecahedron()
glutWireSphere(radius, slices, stacks)
glutWireTeapot(size)
glutWireTetrahedron()
glutWireTorus(innerRadius, outerRadius, nsides, rings)
